==> vertigo-dynamo-impl-1.0.0-test-sources.jar: io/vertigo/dynamo/collections/data/domain/SmartCar.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013-2017, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.dynamo.collections.data.domain;

import io.vertigo.dynamo.domain.model.KeyConcept;
import io.vertigo.dynamo.domain.model.URI;
import io.vertigo.dynamo.domain.stereotype.Field;
import io.vertigo.dynamo.domain.util.DtObjectUtil;

public final class SmartCar implements KeyConcept {
	/** SerialVersionUID. */
	private static final long serialVersionUID = 1L;

	@Field(domain = "DO_ID", type = "ID", required = true, label = "identifiant de la voiture")
	private Long id;
	@Field(domain = "DO_KEYWORD", required = true, label = "Constructeur")
	private String maker;
	@Field(domain = "DO_INTEGER", required = true, label = "Année")
	private Integer year;
	@Field(domain = "DO_TEXT", required = true, label = "Descriptif")
	private String description;

	/** {@inheritDoc} */
	@Override
	public URI<SmartCar> getURI() {
		return DtObjectUtil.createURI(this);
	}

	public final Long getId() {
		return id;
	}

	public void setId(final Long id) {
		this.id = id;
	}

	public String getMaker() {
		return maker;
	}

	public void setMaker(final String maker) {
		this.maker = maker;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(final String description) {
		this.description = description;
	}

	public Integer getYear() {
		return year;
	}

	public void setYear(final Integer year) {
		this.year = year;
	}

	/** {@inheritDoc} */
	@Override
	public String toString() {
		return DtObjectUtil.toString(this);
	}
}

==> vertigo-dynamo-impl-1.1.2-test-sources.jar: io/vertigo/dynamo/collections/data/domain/SmartCar.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013-2018, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.dynamo.collections.data.domain;

import io.vertigo.dynamo.domain.model.KeyConcept;
import io.vertigo.dynamo.domain.model.URI;
import io.vertigo.dynamo.domain.stereotype.Field;
import io.vertigo.dynamo.domain.util.DtObjectUtil;

public final class SmartCar implements KeyConcept {
	/** SerialVersionUID. */
	private static final long serialVersionUID = 1L;

	@Field(domain = "DO_ID", type = "ID", required = true, label = "identifiant de la voiture")
	private Long id;
	@Field(domain = "DO_KEYWORD", required = true, label = "Constructeur")
	private String manufacturer;
	@Field(domain = "DO_INTEGER", required = true, label = "Année")
	private Integer year;
	@Field(domain = "DO_TEXT", required = true, label = "Descriptif")
	private String description;

	/** {@inheritDoc} */
	@Override
	public URI<SmartCar> getURI() {
		return DtObjectUtil.createURI(this);
	}

	public final Long getId() {
		return id;
	}

	public void setId(final Long id) {
		this.id = id;
	}

	public String getManufacturer() {
		return manufacturer;
	}

	public void setManufacturer(final String manufacturer) {
		this.manufacturer = manufacturer;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(final String description) {
		this.description = description;
	}

	public Integer getYear() {
		return year;
	}

	public void setYear(final Integer year) {
		this.year = year;
	}

	/** {@inheritDoc} */
	@Override
	public String toString() {
		return DtObjectUtil.toString(this);
	}
}
